---
hide:
    - toc
---
# Radial Plot

This tool can be used to compare individual models across each task in the benchmark,
using a so-called radial plot (also known as a spider plot). You can access the
underlying Hugging Face Space [here](https://huggingface.co/spaces/alexandrainst/radial-plot-generator).

<script
 type="module"
 src="https://gradio.s3-us-west-2.amazonaws.com/4.39.0/gradio.js"
></script>

<gradio-app src="https://alexandrainst-radial-plot-generator.hf.space"></gradio-app>
